import * as ask from "./ast";
import { Project } from "./project";
import { SourceFile } from "./source-file";
/**
 * Called when decompiling UI skill to move files from locale directories to conversations/ and to
 * add skill.acdl
 * @param project Project
 * @param localesUsed locales used in the project as returned from getUISkillInformation
 * @returns the project reloaded after files creation
 */
export declare function transformUIProjectForDecompile(project: Project, localesUsed: Set<string>): Promise<Project>;
/**
 * Passes each source to resolveUIModule, where it updates the namespaces and relative paths to prompts
 * @param project Project
 * @param localesUsed locales used in the project as returned from getUISkillInformation
 * @param willMoveASKIRUp true when migrating to CLI when the files like "conversations/en-US/audio_response.json" are moved to
 * "conversations/". When this happens response paths need one less '../'
 * @returns project with updated namespaces and relative paths to prompts
 */
export declare function transformUIProject(project: Project, localesUsed: Set<string>, willMoveASKIRUp: boolean): Project;
/**
 * A skill is UI skill if it has the following directory structure and file names
 * conversations/<locale>/6 JSON files of names (variable UIFileNames in this method)
 * @param project Project
 * @returns an object indicating if it is a UI skill and, if so, what locales are used
 */
export declare function getUISkillInformation(sourceModules: SourceFile<ask.Module | undefined>[]): {
    isUISkill: boolean;
    localesUsed: Set<string>;
};
//# sourceMappingURL=transformUIProject.d.ts.map